@@ -1,11 +1,15 @@
 # (C) Datadog, Inc. 2020-present
 # All rights reserved
 # Licensed under the Apache license (see LICENSE)
+from __future__ import annotations
+
 import re
 from typing import Callable, Iterable, Iterator
 
 
-def replace_blocks(lines: Iterable[str], title: str, replace: Callable[..., Iterable[str]]) -> Iterator[str]:
+def replace_blocks(
+    lines: Iterable[str], title: str, replace: Callable[..., Iterable[str]]
+) -> Iterator[str]:
     """
     Find blocks of lines in the form of:
 
@@ -22,13 +26,13 @@ def replace_blocks(lines: Iterable[str], title: str, replace: Callable[..., Iter
 
     for line in lines:
         if in_block_section:
-            match = re.search(r"^\s+:(?P<key>.+):(?:\s+(?P<value>\S+))?", line)
+            match = re.search(r"^\s+:(?P<key>.+):(?:\s+(?P<value>.*\S))?", line)
             if match is not None:
                 # New ':key:' or ':key: value' line, ingest it.
                 key = match.group("key")
                 value = match.group("value") or ""
                 if value.lower() in ["true", "false"]:
-                    value = True if value.lower() == "true" else False
+                    value = value.lower() == "true"
                 options[key] = value
                 continue
 
@@ -45,3 +49,6 @@ def replace_blocks(lines: Iterable[str], title: str, replace: Callable[..., Iter
             options = {}
         else:
             yield line
+
+    if in_block_section:
+        yield from replace(**options)
